// ConsoleApplication1.cpp : Defines the entry point for the console application.
//

#include "pch.h"
#include <process.h>

#include "..\..\..\..\Source\Serial\wclSerialDevices.h"

using namespace std;
using namespace wclCommon;
using namespace wclSerial;

class CUsbMonitor
{
private:
	HANDLE	TerminateEvent;
	HANDLE	Thread;

	string wtoa(const tstring& w)
	{
		return string(w.begin(), w.end());
	}

	string btoa(const bool b)
	{
		if (b)
			return "true";
		return "false";
	}

	void Monitor_OnRemoved(void* Sender, const wclUsbDevice& Device)
	{
		UNREFERENCED_PARAMETER(Sender);

		cout << "Device REMOVED: " << endl;
		cout << "  Friendly name: " << wtoa(Device.FriendlyName).c_str() << endl;
		cout << "  Hardware ID: " << wtoa(Device.HardwareId).c_str() << endl;
		cout << "  Instance: " << wtoa(Device.Instance).c_str() << endl;
		cout << "  Manufacturer: " << wtoa(Device.Manufacturer).c_str() << endl;
	}
	
	void Monitor_OnInserted(void* Sender, const wclUsbDevice& Device)
	{
		UNREFERENCED_PARAMETER(Sender);

		cout << "Device INSERTED: " << endl;
		cout << "  Friendly name: " << wtoa(Device.FriendlyName).c_str() << endl;
		cout << "  Hardware ID: " << wtoa(Device.HardwareId).c_str() << endl;
		cout << "  Instance: " << wtoa(Device.Instance).c_str() << endl;
		cout << "  Manufacturer: " << wtoa(Device.Manufacturer).c_str() << endl;
	}

	static UINT __stdcall _ThreadProc(LPVOID Param)
	{
		((CUsbMonitor*)Param)->ThreadProc();
		return 0;
	}
	
	void ThreadProc()
	{
		CwclUsbMonitor* Monitor = new CwclUsbMonitor();
		__hook(&CwclUsbMonitor::OnInserted, Monitor, &CUsbMonitor::Monitor_OnInserted);
		__hook(&CwclUsbMonitor::OnRemoved, Monitor, &CUsbMonitor::Monitor_OnRemoved);
		
		cout << "Enumerate installed USB devices" << endl;
		wclUsbDevices Devices;
		int Res = Monitor->EnumDevices(Devices);
		if (Res != WCL_E_SUCCESS)
			cout << "Failed to enumerate USB devices: 0x" << hex << Res << dec << endl;
		else
		{
			if (Devices.size() == 0)
				cout << "No USB devices were found" << endl;
			else
			{
				int n = 0;
				for (wclUsbDevices::iterator i = Devices.begin(); i != Devices.end(); i++)
				{
					cout << "Device " << n;
					cout << "  Friendly name: " << wtoa((*i).FriendlyName).c_str() << endl;
					cout << "  Hardware ID: " << wtoa((*i).HardwareId).c_str() << endl;
					cout << "  Instance: " << wtoa((*i).Instance).c_str() << endl;
					cout << "  Manufacturer: " << wtoa((*i).Manufacturer).c_str() << endl;
					n++;
				}
			}
		}
		
		cout << "Try tp start monitoring USB device." << endl;
		Res = Monitor->Start();
		if (Res != WCL_E_SUCCESS)
			cout << "Failed to start monitoring USB devices 0x" << hex << Res << dec << endl;
		else
			cout << "Monitoring started" << endl;

		CwclMessageBroadcaster::Wait(TerminateEvent);
		
		if (Monitor->Monitoring)
		{
			cout << "Try to stop monitoring" << endl;
			Res = Monitor->Stop();
			if (Res != WCL_E_SUCCESS)
				cout << "Failed to stop monitoring USB devices 0x" << hex << Res << dec << endl;
			else
				cout << "Monitoring stopped" << endl;
		}
		
		__unhook(Monitor);
		delete Monitor;
	}
	
public:
	CUsbMonitor()
	{
		TerminateEvent = NULL;
		Thread = NULL;
	}
	
	void Start()
	{
		TerminateEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
		Thread = (HANDLE)_beginthreadex(NULL, 0, _ThreadProc, this, 0, NULL);
	}
	
	void Stop()
	{
		SetEvent(TerminateEvent);
		WaitForSingleObject(Thread, INFINITE);
		CloseHandle(Thread);
		
		CloseHandle(TerminateEvent);
	}
};

int main(int argc, char **argv)
{
	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	CwclMessageBroadcaster::SetSyncMethod(skApc);

	system("cls");
	cout << "USB MONITOR DEMO" << endl;
	cout << "===================" << endl;
	cout << "The demo shows how to enumerate and monitor USB devices." << endl;
	
	CUsbMonitor* Monitor = new CUsbMonitor();
	Monitor->Start();
	system("pause");
	Monitor->Stop();
	delete Monitor;
}
